@@ -198,12 +198,23 @@ class ISolgemaFullcalendarProperties(Interface):
                                   description = _(u"help_displayUndefined"),
                                   default=False)
 
+    overrideStateForAdmin = schema.Bool( title=_(u"label_overrideStateForAdmin"),
+                                  required = False,
+                                  description = _(u"help_overrideStateForAdmin"),
+                                  default=True)
+
     def isSolgemaFullcalendar(self):
         """get name of days"""
 
 class ISolgemaFullcalendarEvents(Interface):
     """Solgema Fullcalendar update view interface"""
 
+class ISolgemaFullcalendarEditableFilter(Interface):
+    """Solgema Fullcalendar update view interface"""
+
+    def filterEvents(self, args):
+        """custom method that filters and returns list of paths of the events that can be edited"""
+
 class ISolgemaFullcalendarMarker(Interface):
     """A marker for items that can be displayed as solgemafullcalendar_view"""
 
