@@ -266,12 +266,30 @@ function readCookie(name) {
   };
 
   jq(document).ready(function() {
+    var thisYear = SolgemaFullcalendarVars.year;
+    var thisMonth = SolgemaFullcalendarVars.monthNunber;
+    var thisDate = SolgemaFullcalendarVars.date;
+    var shour = SolgemaFullcalendarVars.firstHour;
+    if (shour.substring(0,1) == '+' ) {
+        var curDate = new Date();
+        var curHour = curDate.getHours();
+        var firstHour = curHour+shour.substring(1,shour.length);
+    } else if (shour.substring(0,1) == '-' ) {
+        var curDate = new Date();
+        var curHour = curDate.getHours();
+        var firstHour = curHour-shour.substring(1,shour.length);
+    } else {
+        var firstHour = shour;
+    }
     var calendar = jq('#calendar').fullCalendar({
       slotMinutes : SolgemaFullcalendarVars.slotMinutes,
       defaultView: (readCookie('SFView')) ? readCookie('SFView') : SolgemaFullcalendarVars.defaultView,
       firstDay : SolgemaFullcalendarVars.firstDay,
       weekends : SolgemaFullcalendarVars.weekends,
-      firstHour : SolgemaFullcalendarVars.firstHour,
+      year : thisYear,
+      month : thisMonth,
+      date : thisDate,
+      firstHour : firstHour,
       minTime : SolgemaFullcalendarVars.minTime,
       maxTime : SolgemaFullcalendarVars.maxTime,
       height : SolgemaFullcalendarVars.calendarHeight,
@@ -407,6 +425,3 @@ function readCookie(name) {
       }
     });
   });
-
-
-
